from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.consts import assets2


docs = [
    {
        "path": "../docs/cheshmak/body/v1.md",
        "items": ImageItems(
            {
                **{
                    (assets2 + "bryce/{}?raw=true").format(f"{index+1:02}.jpg"): ""
                    for index in range(8)
                }
            }
        ),
    },
]



from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.swallow_head import image_template, latest_version

docs = [
    {
        "path": f"../docs/swallow-head/v{version}.md",
        "items": ImageItems(
            {
                image_template(version).format(
                    f"{index+1:02}.jpg",
                ): ""
                for index in range(6)
            }
        ),
    }
    for version in range(1, latest_version)
]



from bluer_sbc.README.design import design_doc
from bluer_sbc.README.designs.anchor import parts, terraform
from bluer_sbc.README.designs.anchor.body import docs as body
from bluer_sbc.README.designs.anchor.items import items

docs = (
    [
        {
            "path": "../docs/anchor",
            "items": items,
        }
    ]
    + body.docs
    + parts.docs
    + terraform.docs
)



from bluer_objects import README
from bluer_objects.README.items import ImageItems

from bluer_sbc.README.designs.consts import assets2


latest_version: int = 2


def image_template(version: int) -> str:
    return assets2 + f"swallow/design/head-v{version}/{{}}?raw=true"


marquee = README.Items(
    [
        {
            "name": "swallow head",
            "marquee": image_template(latest_version).format("01.jpg"),
            "url": "./bluer_sbc/docs/swallow-head",
        }
    ]
)



from bluer_sbc.README.designs.cheshmak import operation, parts, terraform, validations
from bluer_sbc.README.designs.cheshmak.items import items
from bluer_sbc.README.designs.cheshmak.body import docs as body


docs = (
    [
        {
            "path": "../docs/cheshmak",
            "items": items,
        }
    ]
    + body.docs
    + operation.docs
    + parts.docs
    + terraform.docs
    + validations.docs
)



# pylint: skip-file

specifications = {
    "rpi-ir": {
        "height": 1944,
        "width": 2592,
        "diagonal": 3240,
        "fov": {
            "diagonal": 80,
            "horizontal": 64,
            "vertical": 48,
        },
    },
    "rpi-noir": {
        "height": 1944,
        "width": 2592,
        "diagonal": 3240,
        "fov": {
            "horizontal": 62.2,
            "vertical": 48.8,
        },
    },
    "rpi-rgb": {
        "height": 1944,
        "width": 2592,
        "diagonal": 3240,
        "fov": {
            "horizontal": 62.2,
            "vertical": 48.8,
        },
    },
}



from bluer_sbc.README.designs.swallow import parts
from bluer_sbc.README.designs.swallow import body
from bluer_sbc.README.designs.swallow.items import items


docs = (
    [
        {
            "path": "../docs/swallow",
            "items": items,
        }
    ]
    + body.docs
    + parts.docs
)
